@@ -3,21 +3,23 @@
 kakasi <- function(x, kakasi.option="-Ha -Ka -Ja -Ea -ka", invisible=TRUE) {
   K <- Sys.which("kakasi")
   if (nchar(K) == 0 || !file.exists(K)) stop("kakasi not found")
-  k.cmd <- function(i, encoding.from, encoding.to){
-    cmd <- paste("echo ",i,"| kakasi ",kakasi.option,"-i",encoding.from,
+  k.cmd <- function(i, encoding.from, encoding.to, echo){
+    cmd <- paste(echo,i,"| kakasi ",kakasi.option,"-i",encoding.from,
                  "-o",encoding.to)
     return(cmd)
   }    
   if (.Platform$OS.type == "windows") {
     encoding.from <- "sjis"
     encoding.to <- "sjis"
-    res <- sapply(x, function(i) system(k.cmd(i, encoding.from, encoding.to),
+    echo <- "cmd /C echo"
+    res <- sapply(x, function(i) system(k.cmd(i, encoding.from, encoding.to, echo),
                                         intern=TRUE, invisible=invisible))
     }
   else {
     encoding.from <- "utf8"
     encoding.to <- "utf8"
-    res <- sapply(x, function(i) system(k.cmd(i, encoding.from, encoding.to), intern=TRUE))
+    echo <- "echo"
+    res <- sapply(x, function(i) system(k.cmd(i, encoding.from, encoding.to, echo), intern=TRUE))
     }
   if (any(grep("Can't init", res))) 
     stop("Cannot run kakasi: check connexion")
